<?php

namespace Eform\Business\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Eform\Business\Actions\BusinessAction;
use Eform\Business\Http\Requests\BusinessActionRequest;
use Eform\Business\Http\Resources\BusinessResource;
use Eform\Business\Models\Business;

/**
 * Admin web controller class.
 */
class BusinessActionController extends BaseController
{

    /**
     * Action controller function for business.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(BusinessActionRequest $request, Business $business, $action)
    {
        try {
            $request = $request->all();
            $business = BusinessAction::run($action, $business, $request);

            $data = new BusinessResource($business);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('business::business.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('business/business/' . $business->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('business/business/' . $business->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
