<?php

namespace Eform\Business\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Illuminate\Support\Str;
use Eform\Business\Actions\BusinessExim;
use Eform\Business\Http\Requests\BusinessEximRequest;

/**
 * Admin web controller class.
 */
class BusinessEximController extends BaseController
{
    /**
     * Action controller function for business.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(BusinessEximRequest $request, $exim)
    {
        try {
            $function = Str::camel($exim);
            $data = BusinessExim::$function($request);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('business:business.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('business/business/' . $exim))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('business/business/' . $exim))
                ->redirect();
        }
    }
}
